util module
===========

This modules contains simple utility codes (sorting, file handling etc) that pyatomdb relies on.

.. automodule:: pyatomdb.util
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
